@@ -15,7 +15,7 @@ except ImportError:
         units = []
         if sentence.analyzed and sentence.gloss:
             slices = {sl.index: sl for sl in sentence.forms}
-            g_shift = 0 # to keep up to date with how many g-words there are in total
+            g_shift = 0  # to keep up to date with how many g-words there are in total
             for pwc, (pword, pgloss) in enumerate(
                 zip(sentence.analyzed.split("\t"), sentence.gloss.split("\t"))
             ):
@@ -23,7 +23,7 @@ except ImportError:
                 glosses = []
                 for gwc, (word, gloss) in enumerate(
                     zip(pword.split("="), pgloss.split("="))
-                ):  
+                ):
                     i = pwc + gwc + g_shift
                     if gwc > 0:
                         g_shift += 1
@@ -33,9 +33,13 @@ except ImportError:
                         g_words.append(HTML.span(word))
                         glosses.append(HTML.span(gloss))
                     else:
-                        g_words.append(HTML.span(link(request, slices[i].form), name=slices[i].form.id))
+                        g_words.append(
+                            HTML.span(
+                                link(request, slices[i].form), name=slices[i].form.id
+                            )
+                        )
                         glosses.append(HTML.span(gloss))
-            
+
                 units.append(
                     HTML.div(
                         HTML.div(*g_words),
@@ -97,6 +101,7 @@ def rendered_sentence(
     text_link=True,
     sentence_link=False,
     counter_class="example",
+    example_id=None,
 ):
     """Format a sentence as HTML."""
     if sentence.xhtml:
@@ -121,7 +126,7 @@ def rendered_sentence(
         )
     else:
         surface = HTML.div(sentence.name, " ", class_="object-language")
-    if text_link:
+    if text_link and len(sentence.text_assocs) > 0:
         text = sentence.text_assocs[0].text
         text_ref = (
             " ("
@@ -136,14 +141,14 @@ def rendered_sentence(
             "",
             HTML.source(src=f"/audio/{sentence.audio}", type="audio/x-wav"),
             controls="controls",
-            preload="none"
+            preload="none",
         )
     else:
         audio_content = ""
 
     sentence_content = HTML.div(
         HTML.div(
-            HTML.a(id=sentence.id),
+            HTML.a(id=example_id or sentence.id),
             HTML.div(
                 HTML.div(sentence.original_script, class_="original-script")
                 if sentence.original_script
@@ -163,5 +168,7 @@ def rendered_sentence(
         class_="sentence-wrapper",
     )
     if in_context:
-        return HTML.li(sentence_content, class_=counter_class, id_=sentence.id)
+        return HTML.li(
+            sentence_content, class_=counter_class, id_=example_id or sentence.id
+        )
     return sentence_content
